@@ -12,11 +12,18 @@
 #ifndef _SHARED_UTIL_AUTO_TEST_H_
 #define _SHARED_UTIL_AUTO_TEST_H_
 
-#include <ctime>
+#ifdef WIN32
+    #include <winsock2.h>
+    #include <winsock.h>
+#endif
 
+#include <ctime>
 #include "randomgen.h"
+#include <string>
+#include "game_settings.h"
 #include "leak_dumper.h"
 
+using namespace std;
 using Shared::Util::RandomGen;
 
 namespace Glest{ namespace Game{
@@ -36,20 +43,31 @@ class AutoTest{
 private:
 	int gameStartTime;
 	RandomGen random;
+	bool exitGame;
+	static bool wantExitGame;
+
+	static GameSettings gameSettings;
+	static string loadGameSettingsFile;
 
-private:
 	static const time_t invalidTime;
-	static const time_t gameTime;
+	static time_t gameTime;
 
 public:
 	static AutoTest & getInstance();
 	AutoTest();
 
+	static void setMaxGameTime(time_t value) { gameTime = value; }
+	static void setWantExitGameWhenDone(bool value) { wantExitGame = value; }
+	static string getLoadGameSettingsFile() { return loadGameSettingsFile; }
+	static void setLoadGameSettingsFile(string filename) { loadGameSettingsFile = filename; }
+
+	bool mustExitGame() const { return exitGame; }
+
 	void updateIntro(Program *program);
 	void updateRoot(Program *program, MainMenu *mainMenu);
 	void updateNewGame(Program *program, MainMenu *mainMenu);
 	void updateScenario(MenuStateScenario *menuStateScenario);
-	void updateGame(Game *game);
+	bool updateGame(Game *game);
 	void updateBattleEnd(Program *program);
 };
 
