@@ -31,8 +31,8 @@ const char *mailString				= " http://bugs.megaglest.org";
 
 // !! Use minor versions !!  Only major and minor version control compatibility!
 // typical version numbers look like this: v3.11-beta1.0   v3.12-dev   v3.12.0
-// don't forget to update mk/linux/mg-version.sh
-const string glestVersionString 	= "v3.11.1";
+// don't forget to update source/version.txt
+const string glestVersionString 	= "v3.12.0";
 const string lastCompatibleSaveGameVersionString 	= "v3.9.0";
 
 #if defined(GITVERSION)
@@ -43,7 +43,7 @@ const string lastCompatibleSaveGameVersionString 	= "v3.9.0";
     const string GIT_RawRev			= string(GITVERSION);
     const string GIT_Rev 			= string("Rev: ") + string(GITVERSION);
 #else
-const string GIT_RawRev			= "$5088.9d98d2e$";
+const string GIT_RawRev			= "$5419.034576d$";
 const string GIT_Rev 			= "$Rev$";
 #endif
 
@@ -191,16 +191,16 @@ string getNetworkVersionString() {
 string getNetworkVersionGITString() {
 	static string version = "";
 	if(version == "") {
-			version = glestVersionString + "-" + getCompilerNameString() + "-" + getGITRevisionString();
+		version = glestVersionString + "-" + getGITRevisionString() + "-" + getCompilerNameString();
 	}
 	return version;
 }
 
 string getCompileDateTime() {
 	static string result = "";
-	if(result == "") {
-		result = string(__DATE__) + " " + string(__TIME__);
-	}
+//	if(result == "") {
+//		result = string(__DATE__) + " " + string(__TIME__);
+//	}
 	return result;
 }
 
@@ -209,11 +209,12 @@ string getNetworkPlatformFreeVersionString() {
 }
 
 string getAboutString1(int i) {
+	//case 1: return "Built: " + string(__DATE__) + " " + GIT_Rev;
 	switch(i) {
 	case 0: return "MegaGlest " + glestVersionString + " (" + "Shared Library " + sharedLibVersionString + ")";
-	case 1: return "Built: " + string(__DATE__) + " " + GIT_Rev;
+	case 1: return GIT_Rev;
 	case 2: return "Copyright 2001-2010 The Glest Team";
-	case 3: return "Copyright 2010-2015 The MegaGlest Team";
+	case 3: return "Copyright 2010-2016 The MegaGlest Team";
 	}
 	return "";
 }
