@@ -17,7 +17,6 @@
 #include <algorithm>
 #include "xml_parser.h"
 #include "config.h"
-//#include "util.h"
 #include "platform_common.h"
 #include "conversion.h"
 #include "platform_util.h"
@@ -66,9 +65,10 @@ enum FlagTypes1 {
     ft1_allow_team_switching  			= 0x02,
     ft1_allow_in_game_joining 			= 0x04,
     ft1_network_synch_checks_verbose 	= 0x08,
-    ft1_network_synch_checks 			= 0x10
-    //ft1_xx                  = 0x20,
-    //ft1_xx                  = 0x40,
+    ft1_network_synch_checks 			= 0x10,
+    ft1_allow_shared_team_units         = 0x20,
+    ft1_allow_shared_team_resources     = 0x40
+    //ft1_xxx = 0x80
 };
 
 inline static bool isFlagType1BitEnabled(uint32 flagValue,FlagTypes1 type) {
@@ -85,6 +85,7 @@ enum NetworkPlayerStatusType {
 
 class GameSettings {
 private:
+	string gameName;
 	string description;
 	string map;
 	string tileset;
@@ -189,6 +190,7 @@ public:
 	// default copy constructor will do fine, and will maintain itself ;)
 
 	//get
+	const string &getGameName() const							{return gameName;}
 	const string &getDescription() const							{return description;}
 	const string &getMap() const 									{return map;}
 	const string &getTileset() const								{return tileset;}
@@ -394,6 +396,7 @@ public:
 	const string &getGameUUID() const								{return gameUUID;}
 
 	//set
+	void setGameName(const string& gameName)						{this->gameName= gameName;}
 	void setDescription(const string& description)						{this->description= description;}
 	void setMap(const string& map)										{this->map= map;}
 	void setTileset(const string& tileset)								{this->tileset= tileset;}
@@ -556,6 +559,7 @@ public:
 		string result = "";
 
 		result += "Game ID = " + gameUUID + "\n";
+		result += "gameName = " + gameName + "\n";
 		result += "description = " + description + "\n";
 		result += "mapFilterIndex = " + intToStr(mapFilterIndex) + "\n";
 		result += "map = " + map + "\n";
@@ -590,7 +594,7 @@ public:
 		result += "networkFramePeriod = " + intToStr(networkFramePeriod) + "\n";
 		result += "networkPauseGameForLaggedClients = " + intToStr(networkPauseGameForLaggedClients) + "\n";
 		result += "pathFinderType = " + intToStr(pathFinderType) + "\n";
-		result += "flagTypes1 = " + intToStr(flagTypes1) + "\n";
+		result += "flagTypes1 = " + uIntToStr(flagTypes1) + "\n";
 		result += "mapCRC = " + uIntToStr(mapCRC) + "\n";
 		result += "tilesetCRC = " + uIntToStr(tilesetCRC) + "\n";
 		result += "techCRC = " + uIntToStr(techCRC) + "\n";
@@ -613,6 +617,8 @@ public:
 
 		gameSettingsNode->addAttribute("gameUUID",gameUUID, mapTagReplacements);
 
+//		string gameName;
+		gameSettingsNode->addAttribute("gameName",gameName, mapTagReplacements);
 //		string description;
 		gameSettingsNode->addAttribute("description",description, mapTagReplacements);
 //		string map;
@@ -718,7 +724,7 @@ public:
 //		PathFinderType pathFinderType;
 		gameSettingsNode->addAttribute("pathFinderType",intToStr(pathFinderType), mapTagReplacements);
 //		uint32 flagTypes1;
-		gameSettingsNode->addAttribute("flagTypes1",intToStr(flagTypes1), mapTagReplacements);
+		gameSettingsNode->addAttribute("flagTypes1",uIntToStr(flagTypes1), mapTagReplacements);
 //	    int32 mapCRC;
 		gameSettingsNode->addAttribute("mapCRC",uIntToStr(mapCRC), mapTagReplacements);
 //	    int32 tilesetCRC;
@@ -750,6 +756,13 @@ public:
 			gameUUID = gameSettingsNode->getAttribute("gameUUID")->getValue();
 		}
 
+//		string gameName;
+		if(gameSettingsNode->hasAttribute("gameName") == true) {
+			gameName = gameSettingsNode->getAttribute("gameName")->getValue();
+		}
+		else {
+			gameName = "oldSavegame";
+		}
 //		string description;
 		description = gameSettingsNode->getAttribute("description")->getValue();
 //		string map;
@@ -858,7 +871,7 @@ public:
 //		PathFinderType pathFinderType;
 		pathFinderType = static_cast<PathFinderType>(gameSettingsNode->getAttribute("pathFinderType")->getIntValue());
 //		uint32 flagTypes1;
-		flagTypes1 = gameSettingsNode->getAttribute("flagTypes1")->getIntValue();
+		flagTypes1 = gameSettingsNode->getAttribute("flagTypes1")->getUIntValue();
 //	    int32 mapCRC;
 		mapCRC = gameSettingsNode->getAttribute("mapCRC")->getUIntValue();
 //	    int32 tilesetCRC;
