@@ -98,23 +98,17 @@ MenuBackground::MenuBackground() : rps(NULL) {
 		degToRad(startRotation.z))));
 
 	//load main model
-	mainModel= renderer.newModel(rsMenu);
-	if(mainModel) {
-		string mainModelFile = "data/core/menu/main_model/menu_main.g3d";
-		if(menuNode->hasChild("menu-background-model") == true) {
-			//mainModel->load(data_path + "data/core/menu/main_model/menu_main.g3d");
-			const XmlNode *mainMenuModelNode= menuNode->getChild("menu-background-model");
-			mainModelFile = mainMenuModelNode->getAttribute("value")->getRestrictedValue();
-		}
-		mainModel->load(getGameCustomCoreDataPath(data_path, mainModelFile));
-	}
+    string mainModelFile = "data/core/menu/main_model/menu_main.g3d";
+    if(menuNode->hasChild("menu-background-model") == true) {
+        //mainModel->load(data_path + "data/core/menu/main_model/menu_main.g3d");
+        const XmlNode *mainMenuModelNode= menuNode->getChild("menu-background-model");
+        mainModelFile = mainMenuModelNode->getAttribute("value")->getRestrictedValue();
+    }
+    mainModel = renderer.newModel(rsMenu, getGameCustomCoreDataPath(data_path, mainModelFile));
 
 	//models
-	for(int i=0; i<5; ++i){
-		characterModels[i]= renderer.newModel(rsMenu);
-		if(characterModels[i]) {
-			characterModels[i]->load(getGameCustomCoreDataPath(data_path, "data/core/menu/about_models/character"+intToStr(i)+".g3d"));
-		}
+	for(int i=0; i<5; ++i) {
+		characterModels[i] = renderer.newModel(rsMenu, getGameCustomCoreDataPath(data_path, "data/core/menu/about_models/character"+intToStr(i)+".g3d"));
 	}
 
 	//about position
@@ -122,7 +116,7 @@ MenuBackground::MenuBackground() : rps(NULL) {
 	aboutPosition.x= positionNode->getAttribute("x")->getFloatValue();
 	aboutPosition.y= positionNode->getAttribute("y")->getFloatValue();
 	aboutPosition.z= positionNode->getAttribute("z")->getFloatValue();
-	rotationNode= cameraNode->getChild("about-rotation");
+	//rotationNode= cameraNode->getChild("about-rotation");
 
 	targetCamera= NULL;
 	t= 0.f;
@@ -130,7 +124,31 @@ MenuBackground::MenuBackground() : rps(NULL) {
 	anim= 0.f;
 }
 
+MenuBackground::~MenuBackground() {
+	//printf("In ~MenuBackground() rps = %p\n",rps);
+
+	cleanup();
+}
+
+void MenuBackground::cleanup() {
+	//printf("In MenuBackground::cleanup() rps = %p\n",rps);
+
+	if(rps != NULL) {
+		Renderer &renderer= Renderer::getInstance();
+		if(renderer.validateParticleSystemStillExists(rps,rsMenu) == true) {
+			rps->fade();
+			vector<ParticleSystem *> particleSystems;
+			particleSystems.push_back(rps);
+			renderer.cleanupParticleSystems(particleSystems, rsMenu);
+		}
+
+		rps = NULL;
+	}
+}
+
 void MenuBackground::createRainParticleSystem() {
+	//printf("In MenuBackground::createRainParticleSystem() rps = %p\n",rps);
+
 	if(rps == NULL) {
 		rps= new RainParticleSystem();
 		rps->setSpeed(12.f/GameConstants::updateFps);
@@ -176,17 +194,7 @@ void MenuBackground::update() {
 	else if(rain == true) {
 		rain = false;
 
-		if(rps != NULL) {
-			Renderer &renderer= Renderer::getInstance();
-			if(renderer.validateParticleSystemStillExists(rps,rsMenu) == true) {
-				rps->fade();
-				vector<ParticleSystem *> particleSystems;
-				particleSystems.push_back(rps);
-				renderer.cleanupParticleSystems(particleSystems, rsMenu);
-			}
-
-			rps = NULL;
-		}
+		cleanup();
 	}
 
 	if(targetCamera!=NULL){
