@@ -39,6 +39,14 @@ MenuStateKeysetup::MenuStateKeysetup(Program *program, MainMenu *mainMenu,
 	MenuState(program, mainMenu, "config")
 {
 	try {
+		keyButtonsLineHeight=30;
+		keyButtonsHeight=25;
+		keyButtonsWidth=400;
+		keyButtonsXBase=200;
+		keyButtonsYBase=200+400-keyButtonsLineHeight;
+		keyButtonsToRender=400/keyButtonsLineHeight;
+		int labelWidth=100;
+
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 		containerName = "KeySetup";
 
@@ -48,7 +56,8 @@ MenuStateKeysetup::MenuStateKeysetup(Program *program, MainMenu *mainMenu,
 		hotkeyChar = SDLK_UNKNOWN;
 
 		Lang &lang= Lang::getInstance();
-		int buttonRowPos=80;
+		int buttonStartPos=170;
+		int buttonRowPos=50;
 		if(this->parentUI==NULL){
 			int tabButtonWidth=200;
 			int tabButtonHeight=30;
@@ -87,21 +96,23 @@ MenuStateKeysetup::MenuStateKeysetup(Program *program, MainMenu *mainMenu,
 		}
 		// header
 		labelTitle.registerGraphicComponent(containerName,"labelTitle");
-		labelTitle.init(360,670);
-		labelTitle.setFont(CoreData::getInstance().getMenuFontBig());
-		labelTitle.setFont3D(CoreData::getInstance().getMenuFontBig3D());
-		labelTitle.setText(lang.getString("Keyboardsetup"));
+		labelTitle.init(375,650);
+		labelTitle.setFont(CoreData::getInstance().getMenuFontVeryBig());
+		labelTitle.setFont3D(CoreData::getInstance().getMenuFontVeryBig3D());
+		labelTitle.setText(lang.getString("KeyboardsetupL"));
 
 		labelTestTitle.registerGraphicComponent(containerName,"labelTestTitle");
-		labelTestTitle.init(50,170);
-		labelTestTitle.setFont(CoreData::getInstance().getMenuFontBig());
-		labelTestTitle.setFont3D(CoreData::getInstance().getMenuFontBig3D());
+		labelTestTitle.init(keyButtonsXBase,155);
+		labelTestTitle.setFont(CoreData::getInstance().getMenuFontNormal());
+		labelTestTitle.setFont3D(CoreData::getInstance().getMenuFontNormal3D());
 		labelTestTitle.setText(lang.getString("KeyboardsetupTest"));
 
 		labelTestValue.registerGraphicComponent(containerName,"labelTestValue");
-		labelTestValue.init(50,140);
+		labelTestValue.init(keyButtonsXBase,155-28);
 		labelTestValue.setFont(CoreData::getInstance().getMenuFontBig());
 		labelTestValue.setFont3D(CoreData::getInstance().getMenuFontBig3D());
+		labelTestValue.setRenderBackground(true);
+		labelTestValue.setMaxEditRenderWidth(keyButtonsWidth);
 		labelTestValue.setText("");
 
 		// mainMassegeBox
@@ -116,27 +127,18 @@ MenuStateKeysetup::MenuStateKeysetup(Program *program, MainMenu *mainMenu,
 		keyScrollBar.setVisibleSize(keyButtonsToRender);
 		keyScrollBar.setVisibleStart(0);
 
-
 		// buttons
 		buttonOk.registerGraphicComponent(containerName,"buttonOk");
-		buttonOk.init(200, buttonRowPos, 100);
+		buttonOk.init(buttonStartPos, buttonRowPos, 100);
 		buttonOk.setText(lang.getString("Save"));
 
-		buttonDefaults.registerGraphicComponent(containerName,"buttonDefaults");
-		buttonDefaults.init(310, buttonRowPos, 100);
-		buttonDefaults.setText(lang.getString("Defaults"));
-
 		buttonReturn.registerGraphicComponent(containerName,"buttonReturn");
-		buttonReturn.init(420, buttonRowPos, 100);
+		buttonReturn.init(buttonStartPos+110, buttonRowPos, 100);
 		buttonReturn.setText(lang.getString("Return"));
 
-		keyButtonsLineHeight=30;
-		keyButtonsHeight=25;
-		keyButtonsWidth=400;
-		keyButtonsXBase=200;
-		keyButtonsYBase=200+400-keyButtonsLineHeight;
-		keyButtonsToRender=400/keyButtonsLineHeight;
-		int labelWidth=100;
+		buttonDefaults.registerGraphicComponent(containerName,"buttonDefaults");
+		buttonDefaults.init(buttonStartPos+230, buttonRowPos, 125);
+		buttonDefaults.setText(lang.getString("Defaults"));
 
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 
@@ -155,12 +157,12 @@ MenuStateKeysetup::MenuStateKeysetup(Program *program, MainMenu *mainMenu,
 			string keyName = mergedProperties[i].second;
 			if(keyName.length() > 0) {
 				//char c = configKeys.translateStringToCharKey(keyName);
-				SDLKey c = configKeys.translateStringToSDLKey(keyName);
-				if(c > SDLK_UNKNOWN && c < SDLK_LAST) {
-					SDLKey keysym = static_cast<SDLKey>(c);
+				SDL_Keycode c = configKeys.translateStringToSDLKey(keyName);
+				if(c > SDLK_UNKNOWN && c < SDL_NUM_SCANCODES) {
+					SDL_Keycode keysym = static_cast<SDL_Keycode>(c);
 					// SDL skips capital letters
 					if(keysym >= 65 && keysym <= 90) {
-						keysym = (SDLKey)((int)keysym + 32);
+						keysym = (SDL_Keycode)((int)keysym + 32);
 					}
 					keyName = SDL_GetKeyName(keysym);
 				}
@@ -177,8 +179,10 @@ MenuStateKeysetup::MenuStateKeysetup(Program *program, MainMenu *mainMenu,
 			button->setText(mergedProperties[i].first);
 			keyButtons.push_back(button);
 			GraphicLabel *label=new GraphicLabel();
-			label->init(keyButtonsXBase+keyButtonsWidth+10,keyButtonsYBase,labelWidth,20);
-			label->setText(keyName);
+			label->init(keyButtonsXBase+keyButtonsWidth+5,keyButtonsYBase,labelWidth,20);
+			label->setRenderBackground(true);
+			label->setMaxEditRenderWidth(105);
+			label->setText("  " + keyName);
 			labels.push_back(label);
 		}
 
@@ -207,7 +211,7 @@ void MenuStateKeysetup::reloadUI() {
 	console.resetFonts();
 	labelTitle.setFont(CoreData::getInstance().getMenuFontBig());
 	labelTitle.setFont3D(CoreData::getInstance().getMenuFontBig3D());
-	labelTitle.setText(lang.getString("Keyboardsetup"));
+	labelTitle.setText(lang.getString("KeyboardsetupL"));
 
 	labelTestTitle.setFont(CoreData::getInstance().getMenuFontBig());
 	labelTestTitle.setFont3D(CoreData::getInstance().getMenuFontBig3D());
@@ -318,7 +322,10 @@ void MenuStateKeysetup::mouseClick(int x, int y, MouseButton mouseButton){
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 
         if(userProperties.empty() == false) {
-			Config &configKeys = Config::getInstance(std::pair<ConfigType,ConfigType>(cfgMainKeys,cfgUserKeys));
+        	Config &config = Config::getInstance();
+			Config &configKeys = Config::getInstance(std::pair<ConfigType,ConfigType>(cfgMainKeys,cfgUserKeys),
+					std::pair<string,string>(Config::glestkeys_ini_filename,Config::glestuserkeys_ini_filename),
+					std::pair<bool,bool>(true,false),config.getString("GlestKeysIniPath",""));
 			string userKeysFile = configKeys.getFileName(true);
 	        if(SystemFlags::VERBOSE_MODE_ENABLED) printf("In [%s::%s Line: %d] save file [%s] userProperties.size() = " MG_SIZE_T_SPECIFIER "\n",__FILE__,__FUNCTION__,__LINE__,userKeysFile.c_str(),userProperties.size());
 	        if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] save file [%s] userProperties.size() = " MG_SIZE_T_SPECIFIER "\n",__FILE__,__FUNCTION__,__LINE__,userKeysFile.c_str(),userProperties.size());
@@ -488,10 +495,11 @@ void MenuStateKeysetup::keyDown(SDL_KeyboardEvent key) {
 	//printf("\nkeyDown [%d]\n",hotkeyChar);
 
 	string keyName = "";
-	if(hotkeyChar > SDLK_UNKNOWN && hotkeyChar < SDLK_LAST) {
-		if(SystemFlags::VERBOSE_MODE_ENABLED) printf ("In [%s::%s Line: %d] keyName [%s] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,keyName.c_str(),hotkeyChar,key.keysym.sym);
-		keyName = SDL_GetKeyName(hotkeyChar);
-	}
+	//if(hotkeyChar > SDLK_UNKNOWN && hotkeyChar < SDL_NUM_SCANCODES) {
+	if(SystemFlags::VERBOSE_MODE_ENABLED) printf ("In [%s::%s Line: %d] keyName [%s] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,keyName.c_str(),hotkeyChar,key.keysym.sym);
+	keyName = SDL_GetKeyName(hotkeyChar);
+	//printf ("In [%s::%s Line: %d] keyName [%s] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,keyName.c_str(),hotkeyChar,key.keysym.sym);
+	//}
 	//key = hotkeyChar;
 
 	if(SystemFlags::VERBOSE_MODE_ENABLED) printf ("In [%s::%s Line: %d] keyName [%s] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,keyName.c_str(),hotkeyChar,key.keysym.sym);
@@ -518,8 +526,9 @@ void MenuStateKeysetup::keyDown(SDL_KeyboardEvent key) {
 	char *utfStr = ConvertToUTF8(&szCharText[0]);
 
 	char szBuf[8096] = "";
-	snprintf(szBuf,8096,"%s [%s][%d][%d][%d][%d]",keyName.c_str(),utfStr,key.keysym.sym,hotkeyChar,key.keysym.unicode,key.keysym.mod);
+	snprintf(szBuf,8096,"  %s [%s][%d][%d][%d]",keyName.c_str(),utfStr,key.keysym.sym,hotkeyChar,key.keysym.mod);
 	labelTestValue.setText(szBuf);
+	//printf ("In [%s::%s Line: %d] szBuf [%s]\n",__FILE__,__FUNCTION__,__LINE__,szBuf);
 
 	delete [] utfStr;
 
@@ -536,16 +545,21 @@ void MenuStateKeysetup::keyUp(SDL_KeyboardEvent key) {
     	if(hotkeyChar != 0) {
     		if(SystemFlags::VERBOSE_MODE_ENABLED) printf ("In [%s::%s Line: %d] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,hotkeyChar,key.keysym.sym);
 
-    		string keyName = "";
-			if(hotkeyChar > SDLK_UNKNOWN && hotkeyChar < SDLK_LAST) {
-				keyName = SDL_GetKeyName(hotkeyChar);
-			}
-			key.keysym.sym = hotkeyChar;
+    		//string keyName = "";
+			//if(hotkeyChar > SDLK_UNKNOWN && hotkeyChar < SDL_NUM_SCANCODES) {
+
+    		string keyName = SDL_GetKeyName(key.keysym.sym);
+    		if(StartsWith(keyName,"Keypad ") == false) {
+    			keyName = SDL_GetKeyName(hotkeyChar);
+    			key.keysym.sym = hotkeyChar;
+    		}
+			//}
+			//key.keysym.sym = hotkeyChar;
 
 			if(SystemFlags::VERBOSE_MODE_ENABLED) printf ("In [%s::%s Line: %d] keyName [%s] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,keyName.c_str(),hotkeyChar,key.keysym.sym);
 
 			//SDLKey keysym = SDLK_UNKNOWN;
-			if(keyName == "unknown key" || keyName == "") {
+//			if(keyName == "unknown key" || keyName == "") {
 //				Config &configKeys = Config::getInstance(std::pair<ConfigType,ConfigType>(cfgMainKeys,cfgUserKeys));
 //				keysym = configKeys.translateSpecialStringToSDLKey(hotkeyChar);
 //
@@ -559,7 +573,7 @@ void MenuStateKeysetup::keyUp(SDL_KeyboardEvent key) {
 //					key = keysym;
 //				}
 //				keyName = SDL_GetKeyName(keysym);
-			}
+//			}
 
 			if(SystemFlags::VERBOSE_MODE_ENABLED) printf ("In [%s::%s Line: %d] keyName [%s] char [%d][%d]\n",__FILE__,__FUNCTION__,__LINE__,keyName.c_str(),hotkeyChar,key.keysym.sym);
 
@@ -568,6 +582,16 @@ void MenuStateKeysetup::keyUp(SDL_KeyboardEvent key) {
 				label->setText(keyName);
 
 				pair<string,string> &nameValuePair = mergedProperties[hotkeyIndex];
+
+				// Need to distinguish numeric keys to be translated to real keys
+				// from these ACTUAL sdl keys so surround in quotes.
+				//printf("KeyUp #1 keyName [%s]\n", keyName.c_str());
+
+				if(keyName.size() == 1 && keyName[0] >= '0' && keyName[0] <= '9') {
+					keyName = "'" + keyName + "'";
+				}
+				//printf("KeyUp #2 keyName [%s]\n", keyName.c_str());
+
 				bool isNewUserKeyEntry = true;
 				for(int i = 0; i < (int)userProperties.size(); ++i) {
 					string hotKeyName = userProperties[i].first;
@@ -612,4 +636,5 @@ void MenuStateKeysetup::keyUp(SDL_KeyboardEvent key) {
     }
 }
 
+
 }}//end namespace
