@@ -28,7 +28,6 @@ NetworkManager &NetworkManager::getInstance(){
 
 NetworkManager::NetworkManager() {
 	if(SystemFlags::VERBOSE_MODE_ENABLED) printf("In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
-	if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,gameNetworkInterface);
 
 	gameNetworkInterface= NULL;
 	networkRole= nrIdle;
@@ -36,17 +35,21 @@ NetworkManager::NetworkManager() {
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,gameNetworkInterface);
 }
 
+NetworkManager::~NetworkManager() {
+	end();
+}
+
 void NetworkManager::init(NetworkRole networkRole, bool publishEnabled) {
 	if(SystemFlags::VERBOSE_MODE_ENABLED) printf("In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d, networkRole = %d, gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,networkRole,gameNetworkInterface);
 
-	assert(gameNetworkInterface==NULL);
-
+	//assert(gameNetworkInterface==NULL);
+	NetworkMessage::resetNetworkPacketStats();
 	this->networkRole = networkRole;
 
 	if(networkRole == nrServer) {
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d, networkRole = %d, gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,networkRole,gameNetworkInterface);
-		gameNetworkInterface = new ServerInterface(publishEnabled);
+		gameNetworkInterface = new ServerInterface(publishEnabled,NULL);
 	}
 	else {
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d, networkRole = %d, gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,networkRole,gameNetworkInterface);
@@ -58,6 +61,11 @@ void NetworkManager::init(NetworkRole networkRole, bool publishEnabled) {
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,gameNetworkInterface);
 }
 
+void NetworkManager::initServerInterfaces(ClientLagCallbackInterface *intf) {
+	ServerInterface *server = getServerInterface();
+	server->setClientLagCallbackInterface(intf);
+}
+
 void NetworkManager::end() {
 	if(SystemFlags::VERBOSE_MODE_ENABLED) printf("In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__,__LINE__);
 	if(SystemFlags::getSystemSettingType(SystemFlags::debugNetwork).enabled) SystemFlags::OutputDebug(SystemFlags::debugNetwork,"In [%s::%s Line: %d] this->networkRole = %d gameNetworkInterface [%p]\n",__FILE__,__FUNCTION__,__LINE__,this->networkRole,gameNetworkInterface);
@@ -82,6 +90,10 @@ bool NetworkManager::isNetworkGame() {
 	return networkRole==nrClient || (networkRole==nrServer && getServerInterface()->getSlotCount() > 0);
 }
 
+bool NetworkManager::isNetworkGameWithConnectedClients() {
+	return networkRole==nrClient || (networkRole==nrServer && getServerInterface()->getConnectedSlotCount(true) > 0);
+}
+
 GameNetworkInterface* NetworkManager::getGameNetworkInterface(bool throwErrorOnNull) {
     if(throwErrorOnNull) {
         //assert(gameNetworkInterface!=NULL);
