@@ -17,7 +17,7 @@
 #include "network_types.h"
 #include "byte_order.h"
 #include <map>
-
+#include "common_scoped_ptr.h"
 #include "leak_dumper.h"
 
 using Shared::Platform::Socket;
@@ -49,6 +49,7 @@ enum NetworkMessageType {
 	nmtMarkCell,
 	nmtUnMarkCell,
 	nmtHighlightCell,
+//	nmtCompressedPacket,
 
 	nmtCount
 };
@@ -62,6 +63,7 @@ enum NetworkGameStateType {
 };
 
 static const int maxLanguageStringSize= 60;
+static const int maxNetworkMessageSize= 20000;
 
 // =====================================================
 //	class NetworkMessage
@@ -109,8 +111,13 @@ public:
 	static bool useOldProtocol;
 	virtual ~NetworkMessage(){}
 	virtual bool receive(Socket* socket)= 0;
+	virtual bool receive(Socket* socket, NetworkMessageType type) { return receive(socket); };
+
 	virtual void send(Socket* socket) = 0;
 	virtual size_t getDataSize() const = 0;
+	virtual unsigned char * getData() { return NULL; }
+
+	virtual NetworkMessageType getNetworkMessageType() const = 0;
 
 	void dump_packet(string label, const void* data, int dataSize, bool isSend);
 
@@ -118,6 +125,8 @@ protected:
 	//bool peek(Socket* socket, void* data, int dataSize);
 	bool receive(Socket* socket, void* data, int dataSize,bool tryReceiveUntilDataSizeMet);
 	void send(Socket* socket, const void* data, int dataSize);
+	void send(Socket* socket, const void* data, int dataSize, int8 messageType);
+	void send(Socket* socket, const void* data, int dataSize, int8 messageType, uint32 compressedLength);
 
 	virtual const char * getPackedMessageFormat() const = 0;
 	virtual unsigned int getPackedSize() = 0;
@@ -140,8 +149,8 @@ private:
 	static const int maxSmallStringSize= 60;
 
 private:
+	int8 messageType;
 	struct Data {
-		int8 messageType;
 		int32 sessionId;
 		NetworkString<maxVersionStringSize> versionString;
 		NetworkString<maxNameSize> name;
@@ -154,6 +163,7 @@ private:
 		NetworkString<maxSmallStringSize> playerUUID;
 		NetworkString<maxSmallStringSize> platform;
 	};
+
 	void toEndian();
 	void fromEndian();
 
@@ -175,9 +185,12 @@ public:
 	virtual void unpackMessage(unsigned char *buf);
 	virtual unsigned char * packMessage();
 
-
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtIntro;
+	}
+
 	int32 getSessionId() const 					{ return data.sessionId;}
 	string getVersionString() const				{ return data.versionString.getString(); }
 	string getName() const						{ return data.name.getString(); }
@@ -207,8 +220,8 @@ public:
 #pragma pack(push, 1)
 class NetworkMessagePing: public NetworkMessage{
 private:
+	int8 messageType;
 	struct Data{
-		int8 messageType;
 		int32 pingFrequency;
 		int64 pingTime;
 	};
@@ -231,6 +244,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtPing;
+	}
+
 	int32 getPingFrequency() const	{return data.pingFrequency;}
 	int64 getPingTime() const	{return data.pingTime;}
 	int64 getPingReceivedLocalTime() const { return pingReceivedLocalTime; }
@@ -250,8 +267,8 @@ public:
 #pragma pack(push, 1)
 class NetworkMessageReady: public NetworkMessage{
 private:
+	int8 messageType;
 	struct Data{
-		int8 messageType;
 		uint32 checksum;
 	};
 	void toEndian();
@@ -272,6 +289,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtReady;
+	}
+
 	uint32 getChecksum() const	{return data.checksum;}
 
 	virtual bool receive(Socket* socket);
@@ -294,8 +315,10 @@ private:
 	static const int maxFactionCRCCount= 20;
 
 private:
-	struct Data{
-		int8 messageType;
+
+	int8 messageType;
+	uint32 compressedLength;
+	struct Data {
 		NetworkString<maxStringSize> description;
 		NetworkString<maxSmallStringSize> map;
 		NetworkString<maxSmallStringSize> tileset;
@@ -346,7 +369,7 @@ private:
 	};
 	void toEndian();
 	void fromEndian();
-
+	std::pair<unsigned char *,unsigned long> getCompressedMessage();
 private:
 	Data data;
 
@@ -361,9 +384,14 @@ public:
 	NetworkMessageLaunch(const GameSettings *gameSettings,int8 messageType);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
+	virtual unsigned char * getData();
+
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtLaunch;
+	}
 
 	void buildGameSettings(GameSettings *gameSettings) const;
-	int getMessageType() const { return data.messageType; }
+	int getMessageType() const { return messageType; }
 
 	int getMapCRC() const { return data.mapCRC; }
 	int getTilesetCRC() const { return data.tilesetCRC; }
@@ -371,6 +399,8 @@ public:
 	vector<pair<string,uint32> > getFactionCRCList() const;
 
 	virtual bool receive(Socket* socket);
+	virtual bool receive(Socket* socket, NetworkMessageType type);
+
 	virtual void send(Socket* socket);
 };
 #pragma pack(pop)
@@ -385,8 +415,9 @@ public:
 class NetworkMessageCommandList: public NetworkMessage {
 
 private:
+
 	struct DataHeader {
-		int8 messageType;
+
 		uint16 commandCount;
 		int32 frameCount;
 		uint32 networkPlayerFactionCRC[GameConstants::maxPlayers];
@@ -395,11 +426,12 @@ private:
 	static const int32 commandListHeaderSize = sizeof(DataHeader);
 
 	struct Data {
+		int8 messageType;
 		DataHeader header;
 		std::vector<NetworkCommand> commands;
 	};
 	void init(Data &data_ref) {
-		data_ref.header.messageType = 0;
+		data_ref.messageType = 0;
 		data_ref.header.commandCount = 0;
 		data_ref.header.frameCount = 0;
 		for(int index = 0; index < GameConstants::maxPlayers; ++index) {
@@ -434,6 +466,11 @@ public:
 	NetworkMessageCommandList(int32 frameCount= -1);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
+	virtual unsigned char * getData();
+
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtCommandList;
+	}
 
 	bool addCommand(const NetworkCommand* networkCommand);
 
@@ -462,8 +499,9 @@ private:
 	static const int maxTextStringSize= 500;
 
 private:
+	int8 messageType;
 	struct Data{
-		int8 messageType;
+
 		NetworkString<maxTextStringSize> text;
 		int8 teamIndex;
 		int8 playerIndex;
@@ -482,12 +520,16 @@ protected:
 	virtual unsigned char * packMessage();
 
 public:
-	NetworkMessageText(){}
+	NetworkMessageText();
 	NetworkMessageText(const string &text, int teamIndex, int playerIndex,
 			const string targetLanguage);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtText;
+	}
+
 	string getText() const		{return data.text.getString();}
 	int getTeamIndex() const	{return data.teamIndex;}
 	int getPlayerIndex() const  {return data.playerIndex;}
@@ -508,14 +550,16 @@ public:
 #pragma pack(push, 1)
 class NetworkMessageQuit: public NetworkMessage{
 private:
-	struct Data{
-		int8 messageType;
-	};
+
+	int8 messageType;
+	//struct Data{
+	//	int8 messageType;
+	//};
 	void toEndian();
 	void fromEndian();
 
 private:
-	Data data;
+	//Data data;
 
 protected:
 	virtual const char * getPackedMessageFormat() const;
@@ -526,7 +570,12 @@ protected:
 public:
 	NetworkMessageQuit();
 
-	virtual size_t getDataSize() const { return sizeof(Data); }
+	//virtual size_t getDataSize() const { return sizeof(Data); }
+	virtual size_t getDataSize() const { return 0; }
+
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtQuit;
+	}
 
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
@@ -551,8 +600,6 @@ static const int maxFileCRCPacketCount= 25;
 private:
 
 	struct DataHeader {
-		int8 messageType;
-
 		NetworkString<maxStringSize> map;
 		NetworkString<maxStringSize> tileset;
 		NetworkString<maxStringSize> tech;
@@ -575,6 +622,7 @@ private:
 	static const int32 DetailSize2 = sizeof(uint32);
 
 	struct Data {
+		int8 messageType;
 		DataHeader header;
 		DataDetail detail;
 	};
@@ -607,6 +655,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtSynchNetworkGameData;
+	}
+
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
 
@@ -644,8 +696,6 @@ static const uint32 maxFileCRCPacketCount= 25;
 private:
 
 	struct DataHeader {
-		int8 messageType;
-
 		uint32 mapCRC;
 		uint32 tilesetCRC;
 		uint32 techCRC;
@@ -663,6 +713,7 @@ private:
 	static const int32 DetailSize2 = sizeof(uint32);
 
 	struct Data {
+		int8 messageType;
 		DataHeader header;
 		DataDetail detail;
 	};
@@ -686,6 +737,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtSynchNetworkGameDataStatus;
+	}
+
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
 
@@ -716,8 +771,9 @@ private:
 static const int maxStringSize= 256;
 
 private:
+	int8 messageType;
 	struct Data{
-		int8 messageType;
+
 
 		uint32 totalFileCount;
 		uint32 fileIndex;
@@ -737,11 +793,15 @@ protected:
 	virtual unsigned char * packMessage();
 
 public:
-    NetworkMessageSynchNetworkGameDataFileCRCCheck() {};
+    NetworkMessageSynchNetworkGameDataFileCRCCheck();
 	NetworkMessageSynchNetworkGameDataFileCRCCheck(uint32 totalFileCount, uint32 fileIndex, uint32 fileCRC, const string fileName);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtSynchNetworkGameDataFileCRCCheck;
+	}
+
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
 
@@ -766,8 +826,9 @@ private:
 static const int maxStringSize= 256;
 
 private:
+
+	int8 messageType;
 	struct Data{
-		int8 messageType;
 
 		NetworkString<maxStringSize> fileName;
 	};
@@ -784,11 +845,15 @@ protected:
 	virtual unsigned char * packMessage();
 
 public:
-    NetworkMessageSynchNetworkGameDataFileGet() {};
+    NetworkMessageSynchNetworkGameDataFileGet();
 	NetworkMessageSynchNetworkGameDataFileGet(const string fileName);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtSynchNetworkGameDataFileGet;
+	}
+
 	virtual bool receive(Socket* socket);
 	virtual void send(Socket* socket);
 
@@ -821,8 +886,10 @@ private:
 	static const int maxPlayernameStringSize= 80;
 
 private:
+
+	int8 messageType;
 	struct Data {
-		int8 messageType;
+
 		NetworkString<maxStringSize> selectedFactionName; //wanted faction name
 		int8 currentSlotIndex;
 		int8 toSlotIndex;
@@ -853,6 +920,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtSwitchSetupRequest;
+	}
+
 	string getSelectedFactionName() const	{return data.selectedFactionName.getString();}
 	int getCurrentSlotIndex() const		{return data.currentSlotIndex;}
 	int getToSlotIndex() const			{return data.toSlotIndex;}
@@ -881,8 +952,10 @@ public:
 class PlayerIndexMessage: public NetworkMessage{
 
 private:
+
+	int8 messageType;
 	struct Data {
-		int8 messageType;
+
 		int16 playerIndex;
 	};
 	void toEndian();
@@ -902,6 +975,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtPlayerIndexMessage;
+	}
+
 	int16 getPlayerIndex() const	{return data.playerIndex;}
 
 	virtual bool receive(Socket* socket);
@@ -940,8 +1017,10 @@ enum NetworkMessageLoadingStatusType {
 #pragma pack(push, 1)
 class NetworkMessageLoadingStatus : public NetworkMessage {
 private:
+
+	int8 messageType;
 	struct Data {
-		int8 messageType;
+
 		uint32 status;
 	};
 	void toEndian();
@@ -962,6 +1041,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtLoadingStatusMessage;
+	}
+
 	uint32 getStatus() const	{return data.status;}
 
 	virtual bool receive(Socket* socket);
@@ -982,8 +1065,10 @@ private:
 	static const int maxTextStringSize= 500;
 
 private:
+
+	int8 messageType;
 	struct Data{
-		int8 messageType;
+
 
 		int16 targetX;
 		int16 targetY;
@@ -1004,11 +1089,15 @@ protected:
 	virtual unsigned char * packMessage();
 
 public:
-	NetworkMessageMarkCell(){}
+	NetworkMessageMarkCell();
 	NetworkMessageMarkCell(Vec2i target, int factionIndex, const string &text, int playerIndex);
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtMarkCell;
+	}
+
 	string getText() const			{ return data.text.getString(); }
 	Vec2i getTarget() const		{ return Vec2i(data.targetX,data.targetY); }
 	int getFactionIndex() const  { return data.factionIndex; }
@@ -1030,8 +1119,10 @@ public:
 class NetworkMessageUnMarkCell: public NetworkMessage {
 
 private:
+
+	int8 messageType;
 	struct Data {
-		int8 messageType;
+
 
 		int16 targetX;
 		int16 targetY;
@@ -1055,6 +1146,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtUnMarkCell;
+	}
+
 	Vec2i getTarget() const		{ return Vec2i(data.targetX,data.targetY); }
 	int getFactionIndex() const  { return data.factionIndex; }
 
@@ -1077,8 +1172,9 @@ private:
 	static const int maxTextStringSize= 500;
 
 private:
+
+	int8 messageType;
 	struct Data{
-		int8 messageType;
 
 		int16 targetX;
 		int16 targetY;
@@ -1102,6 +1198,10 @@ public:
 
 	virtual size_t getDataSize() const { return sizeof(Data); }
 
+	virtual NetworkMessageType getNetworkMessageType() const {
+		return nmtHighlightCell;
+	}
+
 	Vec2i getTarget() const		{ return Vec2i(data.targetX,data.targetY); }
 	int getFactionIndex() const  { return data.factionIndex; }
 
@@ -1110,7 +1210,6 @@ public:
 };
 #pragma pack(pop)
 
-
 }}//end namespace
 
 #endif
