@@ -27,11 +27,11 @@
 
 namespace Glest{ namespace Game{
 
-using Shared::Sound::StrSound;
-using Shared::Sound::StaticSound;
-using Shared::Sound::SoundPlayer;
-using Shared::Graphics::Vec3f;
-using namespace Shared::PlatformCommon;
+using ::Shared::Sound::StrSound;
+using ::Shared::Sound::StaticSound;
+using ::Shared::Sound::SoundPlayer;
+using ::Shared::Graphics::Vec3f;
+using namespace ::Shared::PlatformCommon;
 
 // =====================================================
 // 	class SoundRenderer
@@ -51,7 +51,7 @@ private:
 	float musicVolume;
 	float ambientVolume;
 
-	Mutex mutex;
+	Mutex *mutex;
 	bool runThreadSafe;
 
 private:
@@ -65,7 +65,7 @@ public:
 	static SoundRenderer &getInstance();
 	bool init(Window *window);
 	void update();
-	virtual void simpleTask(BaseThread *callingThread) { update(); }
+	virtual void simpleTask(BaseThread *callingThread,void *userdata) { update(); }
 	SoundPlayer *getSoundPlayer() const	{return soundPlayer;}
 
 	//music
