@@ -104,12 +104,12 @@ void Command::setUnit(Unit *unit){
      this->unitRef= unit;
 }
 
-std::string Command::toString() const {
+std::string Command::toString(bool translatedValue) const {
 	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__, __LINE__);
 
 	std::string result = "";
 	if(commandType != NULL) {
-		result = "commandType id = " + intToStr(commandType->getId()) + ", desc = " + commandType->toString();
+		result = "commandType id = " + intToStr(commandType->getId()) + ", desc = " + commandType->toString(translatedValue);
 	}
 	else {
 		result = "commandType = NULL";
@@ -134,7 +134,7 @@ std::string Command::toString() const {
 
 	if(unitType != NULL) {
 		result += ", unitTypeId = " + intToStr(unitType->getId());
-		result += ", unitTypeDesc = " + unitType->getReqDesc();
+		result += ", unitTypeDesc = " + unitType->getReqDesc(translatedValue);
 	}
 
 	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d]\n",__FILE__,__FUNCTION__, __LINE__);
@@ -147,6 +147,26 @@ std::string Command::toString() const {
 	return result;
 }
 
+Checksum Command::getCRC() {
+	Checksum crcForCmd;
+
+	crcForCmd.addInt(commandType->getId());
+	crcForCmd.addInt(originalPos.x);
+	crcForCmd.addInt(originalPos.y);
+	crcForCmd.addInt(pos.x);
+	crcForCmd.addInt(pos.y);
+	crcForCmd.addInt(unitRef.getUnitId());
+	crcForCmd.addInt(facing);
+	if(unitType != NULL) {
+		crcForCmd.addInt(unitType->getId());
+	}
+	crcForCmd.addInt(stateType);
+	crcForCmd.addInt(stateValue);
+	crcForCmd.addInt(unitCommandGroupId);
+
+	return crcForCmd;
+}
+
 void Command::saveGame(XmlNode *rootNode, Faction *faction) {
 	std::map<string,string> mapTagReplacements;
 	XmlNode *commandNode = rootNode->addChild("Command");
