@@ -31,7 +31,8 @@ class CommandType;
 
 enum CommandStateType {
 	cst_None,
-	cst_linkedUnit
+	cst_linkedUnit,
+	cst_EmergencyReturnResource
 };
 
 // =====================================================
@@ -90,10 +91,12 @@ public:
     inline void setUnitCommandGroupId(int value) 	{ unitCommandGroupId = value; }
     inline int getUnitCommandGroupId() const		{ return unitCommandGroupId; }
 
-    std::string toString() const;
+    std::string toString(bool translatedValue) const;
 
     void saveGame(XmlNode *rootNode, Faction *faction);
     static Command * loadGame(const XmlNode *rootNode,const UnitType *ut,World *world);
+
+    Checksum getCRC();
 };   
 
 }}//end namespace
