@@ -56,7 +56,7 @@ public:
 
 	int getAmount() const;
 	int getBalance() const;
-	string getDescription() const;
+	string getDescription(bool translatedValue) const;
 
 	void setAmount(int amount);
 	void setBalance(int balance);
@@ -65,6 +65,9 @@ public:
 
     void saveGame(XmlNode *rootNode) const;
     void loadGame(const XmlNode *rootNode, int index,const TechTree *techTree);
+
+    std::string toString() const;
+    Checksum getCRC();
 };
 
 }}// end namespace
