@@ -370,6 +370,7 @@ private:
 	int32 kills;
 	int32 enemyKills;
 	bool morphFieldsBlocked;
+	int oldTotalSight;
 
 	UnitReference targetRef;
 
@@ -471,6 +472,8 @@ private:
 	//static std::map<void *,bool> deletedUnits;
 
 	bool changedActiveCommand;
+	uint32 lastChangedActiveCommandFrame;
+	uint32 changedActiveCommandFrame;
 
 	int32 lastAttackerUnitId;
 	int32 lastAttackedUnitId;
@@ -517,7 +520,7 @@ public:
 
     const FowAlphaCellsLookupItem & getCachedFow() const { return cachedFow; }
     FowAlphaCellsLookupItem getFogOfWarRadius(bool useCache) const;
-    void calculateFogOfWarRadius();
+    void calculateFogOfWarRadius(bool forceRefresh=false);
 
     //queries
     Command *getCurrrentCommandThreadSafe();
@@ -624,10 +627,10 @@ public:
     inline void setLoadType(const ResourceType *loadType)		{this->loadType= loadType;}
     inline void setProgress2(int progress2)					{this->progress2= progress2;}
 	void setPos(const Vec2i &pos,bool clearPathFinder=false);
-	void refreshPos();
+	void refreshPos(bool forceRefresh=false);
 	void setTargetPos(const Vec2i &targetPos);
 	void setTarget(const Unit *unit);
-	void setTargetVec(const Vec3f &targetVec);
+	//void setTargetVec(const Vec3f &targetVec);
 	void setMeetingPos(const Vec2i &meetingPos);
 	void setVisible(const bool visible);
 	inline bool getVisible() const { return visible; }
@@ -635,7 +638,10 @@ public:
 	//render related
     const Model *getCurrentModel();
     Model *getCurrentModelPtr();
-	Vec3f getCurrVector() const;
+	Vec3f getCurrMidHeightVector() const;
+	Vec3f getCurrVectorForParticlesystems() const;
+	Vec3f getCurrVectorAsTarget() const;
+	Vec3f getCurrBurnVector() const;
 	Vec3f getCurrVectorFlat() const;
 	Vec3f getVectorFlat(const Vec2i &lastPosValue, const Vec2i &curPosValue) const;
 
@@ -706,7 +712,7 @@ public:
 	inline string getCurrentUnitTitle() const {return currentUnitTitle;}
 	void setCurrentUnitTitle(string value) { currentUnitTitle = value;}
 
-	void exploreCells();
+	void exploreCells(bool forceRefresh=false);
 
 	inline bool getInBailOutAttempt() const { return inBailOutAttempt; }
 	inline void setInBailOutAttempt(bool value) { inBailOutAttempt = value; }
@@ -783,6 +789,7 @@ public:
 	inline void setUsePathfinderExtendedMaxNodes(bool value) { usePathfinderExtendedMaxNodes = value; }
 
 	void updateTimedParticles();
+	void setMeshPosInParticleSystem(UnitParticleSystem *ups);
 
 	virtual string getUniquePickName() const;
 	void saveGame(XmlNode *rootNode);
@@ -804,12 +811,14 @@ public:
 
 private:
 
+	void cleanupAllParticlesystems();
 	bool isNetworkCRCEnabled();
 	string getNetworkCRCDecHpList() const;
 	string getParticleInfo() const;
 
 	float computeHeight(const Vec2i &pos) const;
 	void calculateXZRotation();
+	void AnimCycleStarts();
 	void updateTarget();
 	void clearCommands();
 	void deleteQueuedCommand(Command *command);
@@ -818,7 +827,13 @@ private:
 	void startDamageParticles();
 
 	uint32 getFrameCount() const;
+
 	void checkCustomizedParticleTriggers(bool force);
+	void checkCustomizedUnitParticleTriggers();
+	void checkCustomizedUnitParticleListTriggers(const UnitParticleSystemTypes &unitParticleSystemTypesList,
+												 bool applySkillChangeParticles);
+	void queueTimedParticles(const UnitParticleSystemTypes &unitParticleSystemTypesList);
+
 	bool checkModelStateInfoForNewHpValue();
 	void checkUnitLevel();
 
