@@ -11,6 +11,7 @@
 
 #include "damage_multiplier.h"
 #include "conversion.h"
+#include "lang.h"
 #include "leak_dumper.h"
 
 using namespace Shared::Util;
@@ -27,6 +28,13 @@ void AttackType::saveGame(XmlNode *rootNode) {
 	attackTypeNode->addAttribute("id",intToStr(id), mapTagReplacements);
 }
 
+string AttackType::getName(bool translatedValue) const	{
+	if(translatedValue == false) return name;
+
+	Lang &lang = Lang::getInstance();
+	return lang.getTechTreeString("AttackTypeName_" + name,name.c_str());
+}
+
 void ArmorType::saveGame(XmlNode *rootNode) {
 	std::map<string,string> mapTagReplacements;
 	XmlNode *armorTypeNode = rootNode->addChild("ArmorType");
@@ -37,6 +45,12 @@ void ArmorType::saveGame(XmlNode *rootNode) {
 	armorTypeNode->addAttribute("id",intToStr(id), mapTagReplacements);
 }
 
+string ArmorType::getName(bool translatedValue) const	{
+	if(translatedValue == false) return name;
+
+	Lang &lang = Lang::getInstance();
+	return lang.getTechTreeString("ArmorTypeName_" + name,name.c_str());
+}
 // =====================================================
 // 	class DamageMultiplierTable
 // =====================================================
@@ -49,25 +63,26 @@ DamageMultiplierTable::DamageMultiplierTable(){
 
 DamageMultiplierTable::~DamageMultiplierTable(){
 	delete [] values;
+	values=NULL;
 }
 
 void DamageMultiplierTable::init(int attackTypeCount, int armorTypeCount){
 	this->attackTypeCount= attackTypeCount;
 	this->armorTypeCount= armorTypeCount;
 	
-	int valueCount= attackTypeCount*armorTypeCount;
-	values= new float[valueCount];
+	int valueCount= attackTypeCount * armorTypeCount;
+	values= new double[valueCount];
 	for(int i=0; i<valueCount; ++i){
 		values[i]= 1.f;
 	}
 }
 
-float DamageMultiplierTable::getDamageMultiplier(const AttackType *att, const ArmorType *art) const{
-	return values[attackTypeCount*art->getId()+att->getId()];
+double DamageMultiplierTable::getDamageMultiplier(const AttackType *att, const ArmorType *art) const {
+	return values[attackTypeCount * art->getId() + att->getId()];
 }
 
-void DamageMultiplierTable::setDamageMultiplier(const AttackType *att, const ArmorType *art, float value){
-	values[attackTypeCount*art->getId()+att->getId()]= value;
+void DamageMultiplierTable::setDamageMultiplier(const AttackType *att, const ArmorType *art, double value) {
+	values[attackTypeCount * art->getId() + att->getId()] = value;
 }
 
 void DamageMultiplierTable::saveGame(XmlNode *rootNode) {
@@ -81,9 +96,9 @@ void DamageMultiplierTable::saveGame(XmlNode *rootNode) {
 	damageMultiplierTableNode->addAttribute("armorTypeCount",intToStr(armorTypeCount), mapTagReplacements);
 
 	int valueCount= attackTypeCount * armorTypeCount;
-	for(unsigned int i=0; i < valueCount; ++i) {
+	for(int i=0; i < valueCount; ++i) {
 		XmlNode *valuesNode = damageMultiplierTableNode->addChild("values");
-		valuesNode->addAttribute("value",intToStr(values[i]), mapTagReplacements);
+		valuesNode->addAttribute("value",doubleToStr(values[i]), mapTagReplacements);
 	}
 }
 
