@@ -53,7 +53,7 @@ public:
 	virtual ~DisplayableType(){};
 
 	//get
-	virtual string getName(bool translatedValue=false) const	 { return name; }
+	virtual string getName(bool translatedValue=false) const;
 	virtual const Texture2D *getImage() const	{ return image; }
 
 	//virtual void saveGame(XmlNode *rootNode) const;
@@ -77,13 +77,13 @@ protected:
 
 public:
 	//get
-	int getUpgradeReqCount() const						{return upgradeReqs.size();}
-	int getUnitReqCount() const							{return unitReqs.size();}
+	int getUpgradeReqCount() const						{return (int)upgradeReqs.size();}
+	int getUnitReqCount() const							{return (int)unitReqs.size();}
 	const UpgradeType *getUpgradeReq(int i) const		{return upgradeReqs[i];}
 	const UnitType *getUnitReq(int i) const				{return unitReqs[i];}
     
     //other
-    virtual string getReqDesc() const;
+    virtual string getReqDesc(bool translatedValue) const;
 
     //virtual void saveGame(XmlNode *rootNode) const;
 };
@@ -109,7 +109,7 @@ public:
 	virtual ~ProducibleType();
 
     //get
-	int getCostCount() const						{return costs.size();}
+	int getCostCount() const						{return (int)costs.size();}
 	const Resource *getCost(int i) const			{return &costs[i];}
 	const Resource *getCost(const ResourceType *rt) const;
 	int getProductionTime() const					{return productionTime;}
@@ -118,10 +118,10 @@ public:
     //varios
     void checkCostStrings(TechTree *techTree);
     
-	virtual string getReqDesc() const;
-	string getResourceReqDesc(bool lineBreaks=true) const;
-	string getUnitAndUpgradeReqDesc(bool lineBreaks=true) const;
-	string getReqDesc(bool ignoreResourceRequirements) const;
+	virtual string getReqDesc(bool translatedValue) const;
+	string getResourceReqDesc(bool lineBreaks,bool translatedValue) const;
+	string getUnitAndUpgradeReqDesc(bool lineBreaks, bool translatedValue) const;
+	string getReqDesc(bool ignoreResourceRequirements, bool translatedValue) const;
 
 //	virtual void saveGame(XmlNode *rootNode) const;
 //	void loadGame(const XmlNode *rootNode);
