@@ -51,6 +51,13 @@ ResourceType::~ResourceType() {
 	}
 }
 
+string ResourceType::getName(bool translatedValue) const {
+	if(translatedValue == false) return name;
+
+	Lang &lang = Lang::getInstance();
+	return lang.getTechTreeString("ResourceTypeName_" + name,name.c_str());
+}
+
 void ResourceType::load(const string &dir, Checksum* checksum, Checksum *techtreeChecksum,
 		std::map<string,vector<pair<string, string> > > &loadedFileList, string techtreePath) {
 
@@ -64,7 +71,7 @@ void ResourceType::load(const string &dir, Checksum* checksum, Checksum *techtre
 		name= lastDir(dir);
 
 		char szBuf[8096]="";
-		snprintf(szBuf,8096,Lang::getInstance().get("LogScreenGameLoadingResourceType","",true).c_str(),formatString(name).c_str());
+		snprintf(szBuf,8096,Lang::getInstance().getString("LogScreenGameLoadingResourceType","",true).c_str(),formatString(getName(true)).c_str());
 		Logger::getInstance().add(szBuf, true);
 
 		string currentPath = dir;
@@ -103,17 +110,14 @@ void ResourceType::load(const string &dir, Checksum* checksum, Checksum *techtre
                 const XmlNode *modelNode= typeNode->getChild("model");
                 string modelPath= modelNode->getAttribute("path")->getRestrictedValue(currentPath);
 
-                model= renderer.newModel(rsGame);
-                if(model) {
-                	model->load(modelPath, false, &loadedFileList, &sourceXMLFile);
-                }
+                model= renderer.newModel(rsGame, modelPath, false, &loadedFileList, &sourceXMLFile);
                 loadedFileList[modelPath].push_back(make_pair(sourceXMLFile,modelNode->getAttribute("path")->getRestrictedValue()));
 
                 if(modelNode->hasChild("particles")){
 					const XmlNode *particleNode= modelNode->getChild("particles");
 					bool particleEnabled= particleNode->getAttribute("value")->getBoolValue();
 					if(particleEnabled == true) {
-						for(int k= 0; k < particleNode->getChildCount(); ++k) {
+						for(int k= 0; k < (int)particleNode->getChildCount(); ++k) {
 							const XmlNode *particleFileNode= particleNode->getChild("particle-file", k);
 							string particlePath= particleFileNode->getAttribute("path")->getRestrictedValue();
 
@@ -188,13 +192,6 @@ void ResourceType::load(const string &dir, Checksum* checksum, Checksum *techtre
 	}
 }
 
-string ResourceType::getName(bool translatedValue) const {
-	if(translatedValue == false) return name;
-
-	Lang &lang = Lang::getInstance();
-	return lang.getTechTreeString("ResourceTypeName_" + name,name.c_str());
-}
-
 // ==================== misc ====================
 
 ResourceClass ResourceType::strToRc(const string &s){
