@@ -53,24 +53,40 @@ private:
 	DamageMultiplierTable damageMultiplierTable;
 	Checksum checksumValue;
 
+	string languageUsedForCache;
+	std::map<string,string> translatedTechNames;
+	std::map<string,std::map<string,string> > translatedTechFactionNames;
+	bool isValidationModeEnabled;
+
 public:
     Checksum loadTech(const string &techName,
-    		set<string> &factions, Checksum* checksum, std::map<string,vector<pair<string, string> > > &loadedFileList);
+    		set<string> &factions, Checksum* checksum,
+    		std::map<string,vector<pair<string, string> > > &loadedFileList,
+    		bool validationMode=false);
     void load(const string &dir, set<string> &factions, Checksum* checksum,
-    		Checksum *techtreeChecksum, std::map<string,vector<pair<string, string> > > &loadedFileList);
+    		Checksum *techtreeChecksum,
+    		std::map<string,vector<pair<string, string> > > &loadedFileList,
+    		bool validationMode=false);
     string findPath(const string &techName) const;
+
     static string findPath(const string &techName, const vector<string> &pathTechList);
+    static bool exists(const string &techName, const vector<string> &pathTechList);
 
     TechTree(const vector<string> pathList);
     ~TechTree();
     Checksum * getChecksumValue() { return &checksumValue; }
 
     //get
-	int getResourceTypeCount() const							{return resourceTypes.size();}
-	int getTypeCount() const									{return factionTypes.size();}
+	int getResourceTypeCount() const							{return (int)resourceTypes.size();}
+	int getTypeCount() const									{return (int)factionTypes.size();}
 	const FactionType *getType(int i) const						{return &factionTypes[i];}
 	const ResourceType *getResourceType(int i) const			{return &resourceTypes[i];}
-	const string getName() const								{return name;}
+	string getName(bool translatedValue=false);
+	string getNameUntranslated() const;
+
+	string getTranslatedName(string techName, bool forceLoad=false, bool forceTechtreeActiveFile=false);
+	string getTranslatedFactionName(string techName, string factionName);
+
 	vector<string> getPathList() const					{return pathList;}
     //const string &getDesc() const								{return desc;}
 
@@ -81,9 +97,16 @@ public:
 	const ResourceType *getResourceType(const string &name) const;
     const ResourceType *getTechResourceType(int i) const;
     const ResourceType *getFirstTechResourceType() const;
-	const ArmorType *getArmorType(const string &name) const;
+
+    const ArmorType *getArmorType(const string &name) const;
 	const AttackType *getAttackType(const string &name) const;
-	float getDamageMultiplier(const AttackType *att, const ArmorType *art) const;
+
+    int getArmorTypeCount() const { return (int)armorTypes.size(); }
+    const ArmorType * getArmorTypeByIndex(int index) const { return &armorTypes[index]; }
+	int getAttackTypeCount() const { return (int)attackTypes.size(); }
+	const AttackType * getAttackTypeByIndex(int index) const { return &attackTypes[index]; }
+
+	double getDamageMultiplier(const AttackType *att, const ArmorType *art) const;
 	std::vector<std::string> validateFactionTypes();
 	std::vector<std::string> validateResourceTypes();
 
