@@ -20,14 +20,66 @@
 #include <stdexcept>
 #include <stdlib.h>
 #include <stdio.h>
+#include <limits>
 #include "byte_order.h"
 //#include <tr1/unordered_map>
 //using namespace std::tr1;
 
+#include "data_types.h"
 #include "leak_dumper.h"
 
+using namespace std;
+using namespace Shared::Platform;
+
 namespace Shared{ namespace Graphics{
 
+template<typename T>
+inline T truncateDecimal(const T &value, int precision=6) {
+	T precNum = 0;
+	if(precision == 0) {
+		precNum = 1;
+	}
+	else if(precision == 1) {
+		precNum = 10;
+	}
+	else if(precision == 2) {
+		precNum = 100;
+	}
+	else if(precision == 3) {
+		precNum = 1000;
+	}
+	else if(precision == 4) {
+		precNum = 10000;
+	}
+	else if(precision == 5) {
+		precNum = 100000;
+	}
+	else if(precision == 6) {
+		precNum = 1000000;
+	}
+	else  {
+		precNum = std::pow((T)10,(T)precision);
+	}
+
+	// See if we can avoid using an int64 for speed
+// To avoid stupid VC++ compiler error: illegal token on right side of '::'
+//#ifdef WIN32
+//#undef max
+//#endif
+//	static int MAX_INT_VALUE = numeric_limits<int>::max();
+//	if((T)value * (T)precNum <= MAX_INT_VALUE) {
+//		int resultInt = (int)((T)value * (T)precNum);
+//		T result = (T)resultInt / precNum;
+//		//printf("=======================\nvalue = %.10f\nresultInt: %d\nprecision: %d\nbecame: %.10f\n----------\n",value,resultInt,precision,result);
+//		return result;
+//	}
+
+	// Must use an int64 since the result is large
+	int64 resultInt = (int64)((T)value * (T)precNum);
+	T result = (T)((long double)resultInt / precNum);
+	return result;
+}
+
 inline std::vector<std::string> TokenizeString(const std::string str,const std::string delimiters) {
 	std::vector<std::string> tokens;
 	// Assume textLine contains the line of text to parse.
@@ -97,6 +149,8 @@ public:
 
 public:
 	Vec2(){
+		x = 0;
+		y = 0;
 	};
 
 	explicit Vec2(T *p){
@@ -205,7 +259,9 @@ public:
 	}
 
 	inline float dist(const Vec2<T> &v) const{
-		return Vec2<T>(v-*this).length();
+		float distance = Vec2<T>(v-*this).length();
+		distance = truncateDecimal<float>(distance,6);
+		return distance;
 	}
 
 	// strict week ordering, so Vec2<T> can be used as key for set<> or map<>
@@ -213,33 +269,26 @@ public:
 		return x < v.x || (x == v.x && y < v.y);
 	}
 
-	inline float length() const{
-#ifdef USE_STREFLOP
-		return static_cast<float>(streflop::sqrt(static_cast<streflop::Simple>(x*x + y*y)));
-#else
-		return static_cast<float>(sqrt(static_cast<float>(x*x + y*y)));
-#endif
+	inline float length() const {
+		float len = static_cast<float>(std::sqrt(static_cast<float>(x*x + y*y)));
+		len = truncateDecimal<float>(len,6);
+		return len;
 	}
 
 	inline void normalize(){
-		T m= length(); 
+		T m= length();
 		x/= m;
 		y/= m;
 	}
 	
-	inline Vec2<T> rotate(float rad){
-		const float
-#ifdef USE_STREFLOP
-			c = streflop::cosf(rad),
-			s = streflop::sinf(rad);
-#else
-			c = cosf(rad),
-			s = sinf(rad);
-#endif
+	inline Vec2<T> rotate(float rad) {
+		float  c = std::cos(rad),
+			   s = std::sin(rad);
+
 		return Vec2<T>(x*c-y*s,x*s+y*c);
 	}
 
-	inline Vec2<T> rotateAround(float rad,const Vec2<T>& pt){
+	inline Vec2<T> rotateAround(float rad,const Vec2<T>& pt) {
 		return pt+(*this-pt).rotate(rad);
 	}
 
@@ -315,14 +364,17 @@ typedef Vec2<double> Vec2d;
 // =====================================================
 
 template<typename T>
-class Vec3{
+class Vec3 {
 public:
 	T x;
 	T y;
 	T z;
 
 public:
-	Vec3(){
+	Vec3() {
+		x = 0;
+		y = 0;
+		z = 0;
 	};
 
 	explicit Vec3(T *p){
@@ -440,26 +492,26 @@ public:
 		return x*v.x + y*v.y + z*v.z;
 	}
 
-	inline float dist(const Vec3<T> &v) const{
-		return Vec3<T>(v-*this).length();
+	inline float dist(const Vec3<T> &v) const {
+		float distance = Vec3<T>(v-*this).length();
+		distance = truncateDecimal<float>(distance,6);
+		return distance;
 	}
 
-	inline float length() const{
-#ifdef USE_STREFLOP
-		return static_cast<float>(streflop::sqrt(static_cast<streflop::Simple>(x*x + y*y + z*z)));
-#else
-		return static_cast<float>(sqrt(x*x + y*y + z*z));
-#endif
+	inline float length() const {
+		float len = static_cast<float>(std::sqrt(x*x + y*y + z*z));
+		len = truncateDecimal<float>(len,6);
+		return len;
 	}
 
-	inline void normalize(){
-		T m= length(); 
+	inline void normalize() {
+		T m= length();
 		x/= m;
 		y/= m;
 		z/= m;
 	}
 
-	inline Vec3<T> getNormalized() const{
+	inline Vec3<T> getNormalized() const {
 		T m= length();
 		return Vec3<T>(x/m, y/m, z/m);
 	}
@@ -565,7 +617,7 @@ typedef Vec3<double> Vec3d;
 // =====================================================
 
 template<typename T>
-class Vec4{
+class Vec4 {
 public:
 	T x;
 	T y;
@@ -573,6 +625,10 @@ public:
 	T w;
 public:
 	Vec4() {
+		x = 0;
+		y = 0;
+		z = 0;
+		w = 0;
 	};
 
 	explicit Vec4(const T *p){
