@@ -33,8 +33,8 @@ bool strToUInt(const string &s, uint32 *i);
 bool strToFloat(const string &s, float *f);
 
 string boolToStr(bool b);
-string uIntToStr(uint32 i);
-string intToStr(int64 i);
+string uIntToStr(const uint64 value);
+string intToStr(const int64 value);
 string intToHex(int i);
 string floatToStr(float f,int precsion=2);
 string doubleToStr(double f,int precsion=2);
@@ -43,6 +43,8 @@ bool IsNumeric(const char *p, bool  allowNegative=true);
 
 string formatNumber(uint64 f);
 
+string getTimeDuationString(int frames, int updateFps);
+
 }}//end namespace
 
 #endif
