@@ -36,7 +36,7 @@
  */
 int ftpRemoveTrailingSlash(char* path)
 {
-	int len = strlen(path);
+	size_t len = strlen(path);
 
 	if(len > 1)
 	{
@@ -44,7 +44,7 @@ int ftpRemoveTrailingSlash(char* path)
 		if(path[len] == '/')
 			path[len] = '\0';
 	}
-	return len;
+	return (int)len;
 }
 
 /**
@@ -166,6 +166,6 @@ char *ftpStrcpy(char *dest, const char *src)
      char       *d = dest;     
      const char *s = src;
 
-     while (*d++ = *s++);
+     while ((*d++ = *s++));
      return dest;
 }
