@@ -32,7 +32,10 @@ ContextGl::ContextGl() : Context() {
 }
 
 void ContextGl::init() {
-	pcgl.init(colorBits, depthBits, stencilBits, (hardware_acceleration != 0), (fullscreen_anti_aliasing  != 0));
+
+	pcgl.init(colorBits, depthBits, stencilBits,
+			  (hardware_acceleration != 0), (fullscreen_anti_aliasing  != 0),
+			  gammaValue);
 }
 
 ContextGl::~ContextGl() {
