@@ -664,8 +664,9 @@ void LogFileThread::addLogEntry(SystemFlags::DebugType type, string logEntry) {
 
 bool LogFileThread::checkSaveCurrentLogBufferToDisk() {
     bool ret = false;
-    if(difftime(time(NULL),lastSaveToDisk) >= 5 ||
-       LogFileThread::getLogEntryBufferCount() >= 1000000) {
+    if(difftime(time(NULL),lastSaveToDisk) >= 5.0 ||
+		(difftime(time(NULL), lastSaveToDisk) >= 2.0 &&
+         LogFileThread::getLogEntryBufferCount() >= 1000000)) {
         lastSaveToDisk = time(NULL);
         ret = true;
     }
