@@ -40,7 +40,7 @@ namespace Shared{ namespace Util{
 Mutex Checksum::fileListCacheSynchAccessor;
 std::map<string,uint32> Checksum::fileListCache;
 
-int crc_table[256] =
+unsigned int crc_table[256] =
 {
 	0x00000000, 0x77073096, 0xee0e612c, 0x990951ba, 0x076dc419, 0x706af48f, 0xe963a535, 0x9e6495a3,
 	0x0edb8832, 0x79dcb8a4, 0xe0d5e91e, 0x97d2d988, 0x09b64c2b, 0x7eb17cbd, 0xe7b82d07, 0x90bf1d91,
@@ -128,6 +128,40 @@ uint32 Checksum::addInt(const int32 &value) {
 	return sum;
 }
 
+uint32 Checksum::addUInt(const uint32 &value) {
+	int8 byte 	= (value >>  0) & 0xFF;
+	addByte(byte);
+	byte  		= (value >>  8) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 16) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 24) & 0xFF;
+	addByte(byte);
+
+	return sum;
+}
+
+uint32 Checksum::addInt64(const int64 &value) {
+	int8 byte 	= (value >>  0) & 0xFF;
+	addByte(byte);
+	byte  		= (value >>  8) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 16) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 24) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 32) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 40) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 48) & 0xFF;
+	addByte(byte);
+	byte 		= (value >> 56) & 0xFF;
+	addByte(byte);
+
+	return sum;
+}
+
 void Checksum::addString(const string &value) {
 	for(unsigned int i = 0; i < value.size(); ++i) {
 		addByte(value[i]);
@@ -261,7 +295,6 @@ bool Checksum::addFileToSum(const string &path) {
 		addString(lastFile(path));
 
 		bool isXMLFile = (EndsWith(path, ".xml") == true);
-		bool inCommentTag=false;
 
 		// Determine the file length
 		ifs.seekg(0, ios::end);
@@ -277,6 +310,7 @@ bool Checksum::addFileToSum(const string &path) {
 		if(SystemFlags::getSystemSettingType(SystemFlags::debugSystem).enabled) SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] buf.size() = %d, path [%s], isXMLFile = %d\n",__FILE__,__FUNCTION__,__LINE__,buf.size(), path.c_str(),isXMLFile);
 
 		if(isXMLFile == true) {
+			bool inCommentTag=false;
 			for(std::size_t i = 0; i < buf.size(); ++i) {
 				// Ignore Spaces in XML files as they are
 				// ONLY for formatting
@@ -343,7 +377,8 @@ uint32 Checksum::getSum() {
 			MutexSafeWrapper safeMutexSocketDestructorFlag(&Checksum::fileListCacheSynchAccessor,string(__FILE__) + "_" + intToStr(__LINE__));
 			if(Checksum::fileListCache.find(iterMap->first) == Checksum::fileListCache.end()) {
 				Checksum fileResult;
-				bool fileAddedOk = fileResult.addFileToSum(iterMap->first);
+				//bool fileAddedOk = fileResult.addFileToSum(iterMap->first);
+				fileResult.addFileToSum(iterMap->first);
 				Checksum::fileListCache[iterMap->first] = fileResult.getSum();
 				//printf("fileAddedOk = %d for file [%s] CRC [%d]\n",fileAddedOk,iterMap->first.c_str(),Checksum::fileListCache[iterMap->first]);
 			}
