@@ -15,9 +15,12 @@
 #include "util.h"
 #include <stdexcept>
 #include "platform_util.h"
+#include "math_util.h"
 #include "leak_dumper.h"
 
 using namespace std;
+using namespace Shared::Graphics;
+
 namespace Shared { namespace Util {
 
 // =====================================================
@@ -29,86 +32,77 @@ const int RandomGen::a= 1366;
 const int RandomGen::b= 150889;
 
 RandomGen::RandomGen(){
-
-//#ifdef USE_STREFLOP
-//	lastNumber = streflop::RandomInit(0); // streflop
-//#else
 	lastNumber= 0;
-//#endif
-	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] lastNumber = %d\n",__FILE__,__FUNCTION__,__LINE__,lastNumber);
+	disableLastCallerTracking = false;
 }
 
 void RandomGen::init(int seed){
-
-//#ifdef USE_STREFLOP
-//	lastNumber = streflop::RandomInit(seed); // streflop
-//#else
 	lastNumber= seed % m;
-//#endif
-
-	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] seed = %d, lastNumber = %d\n",__FILE__,__FUNCTION__,__LINE__,seed,lastNumber);
 }
 
-int RandomGen::rand() {
-	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] lastNumber = %d\n",__FILE__,__FUNCTION__,__LINE__,lastNumber);
-
-	lastNumber= (a*lastNumber + b) % m;
-
-	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] lastNumber = %d\n",__FILE__,__FUNCTION__,__LINE__,lastNumber);
-
+int RandomGen::rand(string lastCaller) {
+	if(lastCaller != "") {
+		this->lastCaller.push_back(lastCaller);
+	}
+	this->lastNumber = (a*lastNumber + b) % m;
 	return lastNumber;
 }
 
-int RandomGen::randRange(int min, int max){
-	assert(min<=max);
+std::string RandomGen::getLastCaller() const {
+	std::string result = "";
+	if(lastCaller.empty() == false) {
+		for(unsigned int index = 0; index < lastCaller.size(); ++index) {
+			result += lastCaller[index] + "|";
+		}
+	}
+	return result;
+}
+
+void RandomGen::clearLastCaller() {
+	if(lastCaller.empty() == false) {
+		lastCaller.clear();
+	}
+}
+void RandomGen::addLastCaller(std::string text) {
+	if(disableLastCallerTracking == false) {
+		lastCaller.push_back(text);
+	}
+}
+
+int RandomGen::randRange(int min, int max,string lastCaller) {
 	if(min > max) {
 		char szBuf[8096]="";
 		snprintf(szBuf,8096,"In [%s::%s Line: %d] min > max, min = %d, max = %d",__FILE__,__FUNCTION__,__LINE__,min,max);
 		throw megaglest_runtime_error(szBuf);
 	}
 
-//#ifdef USE_STREFLOP
-//	int res = streflop::Random<true, false, float>(min, max); // streflop
-//#else
 	int diff= max-min;
-	int res= min + static_cast<int>(static_cast<float>(diff+1)*RandomGen::rand() / m);
-//#endif
-	assert(res>=min && res<=max);
+	float numerator = static_cast<float>(diff + 1) * static_cast<float>(RandomGen::rand(lastCaller));
+	int res= min + static_cast<int>(truncateDecimal<float>(numerator / static_cast<float>(m),6));
 	if(res < min || res > max) {
 		char szBuf[8096]="";
 		snprintf(szBuf,8096,"In [%s::%s Line: %d] res < min || res > max, min = %d, max = %d, res = %d",__FILE__,__FUNCTION__,__LINE__,min,max,res);
 		throw megaglest_runtime_error(szBuf);
 	}
-
-	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] min = %d, max = %d, res = %d\n",__FILE__,__FUNCTION__,__LINE__,min,max,res);
-
 	return res;
 }
 
-float RandomGen::randRange(float min, float max){
-	assert(min<=max);
+float RandomGen::randRange(float min, float max,string lastCaller) {
 	if(min > max) {
 		char szBuf[8096]="";
 		snprintf(szBuf,8096,"In [%s::%s Line: %d] min > max, min = %f, max = %f",__FILE__,__FUNCTION__,__LINE__,min,max);
 		throw megaglest_runtime_error(szBuf);
 	}
 
-//#ifdef USE_STREFLOP
-//	float res = streflop::Random<true, false, float>(min, max, randomState); // streflop
-//#else
-	float rand01= static_cast<float>(RandomGen::rand())/(m-1);
-	float res= min+(max-min)*rand01;
-//#endif
+	float rand01 = static_cast<float>(RandomGen::rand(lastCaller)) / (m-1);
+	float res= min + (max - min) * rand01;
+	res = truncateDecimal<float>(res,6);
 
-	assert(res>=min && res<=max);
 	if(res < min || res > max) {
 		char szBuf[8096]="";
 		snprintf(szBuf,8096,"In [%s::%s Line: %d] res < min || res > max, min = %f, max = %f, res = %f",__FILE__,__FUNCTION__,__LINE__,min,max,res);
 		throw megaglest_runtime_error(szBuf);
 	}
-
-	//SystemFlags::OutputDebug(SystemFlags::debugSystem,"In [%s::%s Line: %d] min = %f, max = %f, res = %f\n",__FILE__,__FUNCTION__,__LINE__,min,max,res);
-
 	return res;
 }
 
